@@ -2,6 +2,8 @@ import time
 from datetime import datetime, tzinfo
 from typing import Any, Callable, Mapping, Sequence, TypedDict, Optional, Union
 
+from typing_extensions import NotRequired
+
 from .backend import Backend
 from .event import EventBridge, Shutdown, Pause, Resume
 from .process import TaskkitProcess
@@ -19,6 +21,16 @@ class ScheduleEntryDict(TypedDict):
     group: str
     name: str
     data: Any
+    result_ttl: NotRequired[Optional[float]]
+
+
+class InitiateTaskArgs(TypedDict):
+    group: str
+    name: str
+    data: Any
+    due: NotRequired[Optional[datetime]]
+    ttl: NotRequired[float]
+    eager: NotRequired[bool]
 
 
 ScheduleEntryCompat = Union[ScheduleEntry, ScheduleEntryDict]
@@ -124,6 +136,7 @@ class Kit:
                 name=entry['name'],
                 data=self.handler.encode_data(
                     entry['group'], entry['name'], entry['data']),
+                result_ttl=entry.get('result_ttl'),
             )
         return entry
 
@@ -134,12 +147,37 @@ class Kit:
                       due: Optional[datetime] = None,
                       ttl: float = DEFAULT_TASK_TTL,
                       eager: bool = False) -> Result[Any]:
-        encoded = self.handler.encode_data(group, name, data)
-        task = Task.init(group, name=name, data=encoded, due=due, ttl=ttl)
-        if eager:
-            return self.eager_worker.handle_task(task)
-        self.backend.put_tasks(task)
-        return Result(self.backend, self.handler, task.id)
+        return self.initiate_tasks({
+            'group': group,
+            'name': name,
+            'data': data,
+            'due': due,
+            'ttl': ttl,
+            'eager': eager,
+        })[0]
+
+    def initiate_tasks(self, *args: InitiateTaskArgs) -> list[Result[Any]]:
+        tasks: list[Task] = []
+        results: list[Result[Any]] = []
+
+        for item in args:
+            group = item['group']
+            name = item['name']
+            data = item['data']
+            due = item.get('due')
+            ttl = item.get('ttl', DEFAULT_TASK_TTL)
+
+            encoded = self.handler.encode_data(group, name, data)
+            task = Task.init(group, name=name, data=encoded, due=due, ttl=ttl)
+            if item.get('eager'):
+                results.append(self.eager_worker.handle_task(task))
+            else:
+                results.append(Result(self.backend, self.handler, task.id))
+                tasks.append(task)
+
+        if tasks:
+            self.backend.put_tasks(*tasks)
+        return results
 
     def get_result(self, task_id: str) -> Result:
         return Result(self.backend, self.handler, task_id)
